/*
 * Copyright © 2008 Sebastian Keller <sebastian-keller@gmx.de>
 * Copyright © 2008 daniel g. siegel <dgsiegel@gmail.com>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __CHEESE_NO_CAMERA_H__
#define __CHEESE_NO_CAMERA_H__

G_BEGIN_DECLS

GtkWidget *cheese_no_camera_info_bar_new (void);

G_END_DECLS

#endif  /* __CHEESE_NO_CAMERA_H__  */
